DefaultTokenManager class

Default TokenManager provided by Kakao Flutter SDK.

Currently uses SharedPreferences (on Android) and UserDefaults (on iOS).

Implemented types

Constructors

DefaultTokenManager()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → Future<void>
Deletes all token information.
override
getToken() → Future<OAuthToken?>
retrieves access token and other information from the designated store.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setToken(OAuthToken token) → Future<void>
stores access token and other retrieved information from AuthApi.issueAccessToken
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

atExpiresAtKey → const String
atKey → const String
rtExpiresAtKey → const String
rtKey → const String
scopesKey → const String
secureModeKey → const String
tokenKey → const String