OAuthToken class

Access token and refresh token information.

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, includeIfNull: false)

Constructors

OAuthToken(String accessToken, DateTime accessTokenExpiresAt, String refreshToken, DateTime refreshTokenExpiresAt, List<String>? scopes)
OAuthToken.fromJson(Map<String, dynamic> json)
factory

Properties

accessToken ↔ String
getter/setter pair
accessTokenExpiresAt ↔ DateTime
Use this field with caution. Token might have expired on server side.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
refreshToken ↔ String
getter/setter pair
refreshTokenExpiresAt ↔ DateTime
Use this field with caution. Token might have expired on server side.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes ↔ List<String>?
List of scopes this user has agreed to when this token was issued.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromResponse(AccessTokenResponse response, {OAuthToken? oldToken}) → OAuthToken