ServerHosts class

List of hosts used by Kakao API.

Constructors

ServerHosts()

Properties

dapi → String
final
hashCode → int
The hash code for this object.
no setterinherited
kapi → String
final
kauth → String
final
pf → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharer → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited