LinkClient class

Constructors

LinkClient(LinkApi api, {Platform? platform})

Properties

api ↔ LinkApi
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

customWithTalk(int templateId, {Map<String, String>? templateArgs, Map<String, String>? serverCallbackArgs}) → Future<Uri>
Send KakaoLink messages with custom templates.
customWithWeb(int templateId, {Map<String, String>? templateArgs, Map<String, String>? serverCallbackArgs}) → Future<Uri>
Send KakaoLink messages with custom templates.
defaultWithTalk(DefaultTemplate template, {Map<String, String>? serverCallbackArgs}) → Future<Uri>
defaultWithWeb(DefaultTemplate template, {Map<String, String>? serverCallbackArgs}) → Future<Uri>
isKakaoLinkAvailable() → Future<bool>
launchKakaoTalk(Uri uri) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scrapImage(String imageUrl, {bool secureResource = true}) → Future<ImageUploadResult>
Upload remote image to Kakao Image Server to use as KakaoLink content image.
scrapWithTalk(String url, {int? templateId, Map<String, String>? templateArgs, Map<String, String>? serverCallbackArgs}) → Future<Uri>
scrapWithWeb(String url, {int? templateId, Map<String, String>? templateArgs, Map<String, String>? serverCallbackArgs}) → Future<Uri>
toString() → String
A string representation of this object.
inherited
uploadImage(File image, {bool secureResource = true}) → Future<ImageUploadResult>
Upload the local image to the Kakao Image Server to use it as a KakaoLink content image.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → LinkClient
singleton instance of this class.
final