Address class

Represents land-lot based address, which is deprecated now.

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, includeIfNull: false)

Constructors

Address(String addressName, String region1depthName, String region2depthName, String region3depthName, String? region3depthHName, String? hCode, String? bCode, String mountainYn, String mainAddressNo, String subAddressNo, String? zipCode, double? x, double? y)
Address.fromJson(Map<String, dynamic> json)
factory

Properties

addressName → String
full land-lot based address
final
bCode → String?
final
hashCode → int
The hash code for this object.
no setterinherited
hCode → String?
final
mainAddressNo → String
final
mountainYn → String
whether this address is in mountain or not
final
region1depthName → String
시 or 도
final
region2depthName → String
구 단위
final
region3depthHName → String?
행정동 단위
final
region3depthName → String
동 단위
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subAddressNo → String
final
x ↔ double?
getter/setter pairinherited
y ↔ double?
getter/setter pairinherited
zipCode → String?
deprecated
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited