LocalSearchMeta class

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, includeIfNull: false)

Constructors

LocalSearchMeta(int totalCount, int pageableCount, bool isEnd, RegionInfo? regionInfo)
LocalSearchMeta.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEnd ↔ bool
Whether current page is the end page. Next request can be made with an incremented page number if this flag is false.
getter/setter pairinherited
pageableCount ↔ int
getter/setter pairinherited
regionInfo ↔ RegionInfo?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCount ↔ int
total number of documents
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited