Region class

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, includeIfNull: false)

Constructors

Region(String regionType, String addressName, String region1depthName, String region2depthName, String region3depthName, String region4depthName, String code, double x, double y)
Region.fromJson(Map<String, dynamic> json)
factory

Properties

addressName → String
final
code → String
final
hashCode → int
The hash code for this object.
no setterinherited
region1depthName → String
final
region2depthName → String
final
region3depthName → String
final
region4depthName → String
final
regionType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x ↔ double
getter/setter pairinherited
y ↔ double
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited