TotalAddress class

Wrapper for land-lot based address and street name adress.

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, includeIfNull: false)

Constructors

TotalAddress(String? addressName, AddressType? addressType, double x, double y, Address? address, RoadAddress? roadAddress)
TotalAddress.fromJson(Map<String, dynamic> json)
factory

Properties

address → Address?
final
addressName → String?
final
addressType → AddressType?
final
hashCode → int
The hash code for this object.
no setterinherited
roadAddress → RoadAddress?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x ↔ double
getter/setter pairinherited
y ↔ double
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited