PushApi class

Provides Kakao Push API.

Annotations
  • @Deprecated("These APIs will be removed when version 1.0.0 is released. If you want to use it, use REST API.")

Constructors

PushApi(Dio dio, Platform platform)

Properties

dio → Dio
final
hashCode → int
The hash code for this object.
no setterinherited
platform → Platform
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deregister(int uuid, String deviceId, {String? pushType}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(int uuid, String deviceId, String pushToken, {String? pushType}) → Future<int>
tokens(int uuid) → Future<List<PushTokenInfo>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → PushApi
final