PushTokenInfo class

Push token this user has registered before.

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, includeIfNull: false)

Constructors

PushTokenInfo(String userId, String deviceId, PushType pushType, String pushToken, DateTime createdAt, DateTime updatedAt)
PushTokenInfo.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → DateTime
final
deviceId → String
final
hashCode → int
The hash code for this object.
no setterinherited
pushToken → String
final
pushType → PushType
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → DateTime
final
userId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited