Commerce class

Represents commerce section data of commerce type template.

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, includeIfNull: false)

Constructors

Commerce(int regularPrice, {int? discountPrice, int? fixedDiscountPrice, int? discountRate, String? productName, String? currencyUnit, int? currencyUnitPosition})
Commerce.fromJson(Map<String, dynamic> json)
factory

Properties

currencyUnit → String?
final
currencyUnitPosition → int?
final
discountPrice → int?
final
discountRate → int?
exclusive with fixedDiscountPrice.
final
fixedDiscountPrice → int?
exclusive with discountRate.
final
hashCode → int
The hash code for this object.
no setterinherited
productName → String?
final
regularPrice → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited