Link class

Collection of links to open whe a specific area in KakaoTalk message is tapped.

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, includeIfNull: false)

Constructors

Link({Uri? webUrl, Uri? mobileWebUrl, Map<String, String>? androidExecutionParams, Map<String, String>? iosExecutionParams})
Link.fromJson(Map<String, dynamic> json)
factory

Properties

androidExecutionParams → Map<String, String>?
query string to be passed to custom scheme in Android.
final
hashCode → int
The hash code for this object.
no setterinherited
iosExecutionParams → Map<String, String>?
query string to be passed to custom scheme in iOS.
final
mobileWebUrl → Uri?
Url to open in mobile KakaoTalk in-app browser.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webUrl → Uri?
Url to open in PC or MacOS KakaoTalk.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited