ListTemplate class

Default template for list type.

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, explicitToJson: true, includeIfNull: false)

Constructors

ListTemplate(String headerTitle, Link headerLink, List<Content> contents, {List<Button>? buttons, String? buttonTitle, String objectType = "list"})
ListTemplate.fromJson(Map<String, dynamic> json)
factory

Properties

buttons → List<Button>?
final
buttonTitle → String?
final
contents → List<Content>
final
hashCode → int
The hash code for this object.
no setterinherited
final
headerTitle → String
final
objectType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited