LocationTemplate class

Default template for location type.

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, explicitToJson: true, includeIfNull: false)

Constructors

LocationTemplate(String address, Content content, {String? addressTitle, Social? social, List<Button>? buttons, String? buttonTitle, String objectType = "location"})
LocationTemplate.fromJson(Map<String, dynamic> json)
factory

Properties

address → String
final
addressTitle → String?
final
buttons → List<Button>?
final
buttonTitle → String?
final
content → Content
final
hashCode → int
The hash code for this object.
no setterinherited
objectType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
social → Social?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited