User class

Response from UserApi.me().

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, explicitToJson: true, includeIfNull: false)

Constructors

User(int id, bool? hasSignedUp, Map<String, String>? properties, Account? kakaoAccount, String? groupUserToken, DateTime? synchedAt, DateTime? connectedAt)
User.fromJson(Map<String, dynamic> json)
factory

Properties

connectedAt ↔ DateTime?
getter/setter pair
groupUserToken ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasSignedUp ↔ bool?
whether this user is connected to the service or not.
getter/setter pair
id ↔ int
app user id
getter/setter pair
kakaoAccount ↔ Account?
getter/setter pair
properties ↔ Map<String, String>?
custom properties this user has.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
synchedAt ↔ DateTime?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited