UserServiceTerms class

Response from UserApi.serviceTerms()

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, explicitToJson: true, includeIfNull: false)

Constructors

UserServiceTerms(int? userId, List<ServiceTerms>? allowedServiceTerms)
UserServiceTerms.fromJson(Map<String, dynamic> json)
factory

Properties

allowedServiceTerms ↔ List<ServiceTerms>?
getter/setter pair
appServiceTerms ↔ List<AppServiceTerms>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited